# Copyright 2021 SpinQ Technology Co., Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .compiler import *
from .qasm_compiler import QASMCompiler
from .ir import IntermediateRepresentation, NodeType


def get_compiler(option: str = 'native') -> Compiler:
    if option == 'qasm':
        return QASMCompiler()


def compiler(option, optimization_level=0):
    c = get_compiler(option)

    def wrapper(fn):
        def new_fn(*args, **kwargs):
            circuit = fn(*args, **kwargs)
            Ir = c.compile(circuit, optimization_level)
            setattr(Ir, 'place_holder', getattr(circuit, 'place_holder', ()))
            return Ir

        return new_fn

    return wrapper
